@@ -9,6 +9,7 @@ from napoleontoolbox.file_saver import dropbox_file_saver
 from napoleontoolbox.signal import signal_generator
 from napoleontoolbox.connector import napoleon_connector
 from napoleontoolbox.signal import signal_utility
+from napoleontoolbox.parallel_run import signal_result_analyzer
 import json
 
 
@@ -54,7 +55,7 @@ import json
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, hourly_pkl_file_name='hourly_candels.pkl',aggregated_pkl_file_name='hourly_to_mix.pkl', aggregated_pkl_mapping_file_name = 'hourly_to_mix_mapping.pkl', list_pkl_file_name = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, hourly_pkl_file_name='hourly_candels.pkl',aggregated_pkl_file_name='hourly_to_mix.pkl', aggregated_pkl_mapping_file_name = 'hourly_to_mix_mapping.pkl', list_pkl_file_name = 'my_list.pkl', local_root_directory='../data/', user = 'napoleon', add_turn_over = False, skipping_size=200, recompute_all = True, db_path_suffix=None):
         super().__init__()
         self.hourly_pkl_file_name=hourly_pkl_file_name
         self.aggregated_pkl_file_name=aggregated_pkl_file_name
@@ -70,6 +71,15 @@ class AbstractRunner(ABC):
         self.skipping_size = skipping_size
         self.signals_list = napoleon_connector.load_pickled_list(local_root_directory=self.local_root_directory,
                                                                  list_pkl_file_name=self.list_pkl_file_name)
+        self.recompute_all = recompute_all
+        self.db_path_suffix = db_path_suffix
+        if not self.recompute_all:
+            saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
+                                                                     local_root_directory=local_root_directory, user=user,
+                                                                     db_path_suffix=self.db_path_suffix)
+            self.precomputed_results_df = saver.analyzeAllRunResults()
+        else:
+            self.precomputed_results_df = None
 
     @abstractmethod
     def runTrial(self,saver,  seed, trigger, signal_type, idios_string, transaction_costs, normalization):
@@ -100,22 +110,26 @@ class EnsemblingSignalRunner(AbstractRunner):
             signal_type = params['signal_type']
             if normalization and not signal_generator.is_signal_continuum(signal_type):
                 return
-            print('Launching computation with parameters : '+run_json_string)
-            print('Signal number '+str(counter))
-            if signal_type == 'long_only':
-                hourly_df['signal']=1.
-            else:
-                lookback_window = params['lookback_window']
-                if self.skipping_size < lookback_window:
-                    raise Exception('The skipping size must be greater than the lookback window')
-                # kwargs = {**generics, **idios}
-                signal_generation_method_to_call = getattr(signal_generator, signal_type)
-                hourly_df = signal_utility.roll_wrapper(hourly_df, lookback_window, self.skipping_size,
-                                          lambda x: signal_generation_method_to_call(data=x, **params), trigger)
-                hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs, normalization = normalization)
-
             signal_column = 'signal'+str(counter)
             mapping_dictionary[me_signal]=[signal_column]
+            if self.recompute_all:
+                print('Launching computation with parameters : '+run_json_string)
+                print('Signal number '+str(counter))
+                if signal_type == 'long_only':
+                    hourly_df['signal']=1.
+                else:
+                    lookback_window = params['lookback_window']
+                    if self.skipping_size < lookback_window:
+                        raise Exception('The skipping size must be greater than the lookback window')
+                    # kwargs = {**generics, **idios}
+                    signal_generation_method_to_call = getattr(signal_generator, signal_type)
+                    hourly_df = signal_utility.roll_wrapper(hourly_df, lookback_window, self.skipping_size,
+                                              lambda x: signal_generation_method_to_call(data=x, **params), trigger)
+                    hourly_df = signal_utility.reconstitute_signal_perf(data = hourly_df, transaction_cost = transaction_costs, normalization = normalization)
+            else :
+                hourly_df = self.precomputed_results_df[me_signal]
+
+
             if cumulated_signals is None:
                 if self.add_turn_over:
                     cumulated_signals = hourly_df[['close','signal','turn_over']]
