@@ -9,6 +9,21 @@ from napoleontoolbox.signal import signal_utility
 import json
 import hashlib
 
+def unjsonize_mapping_dataframe(mapping_df):
+    human_readable_dictionary = {}
+    json_params_dictionary = {}
+    for col in mapping_df.columns :
+        run_json_string = signal_utility.recover_to_sql_column_format(col)
+        #saving_key = signal_utility.convert_to_sql_column_format(run_json_string)
+        salty = str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
+        params = json.loads(run_json_string)
+        readable_label = params['signal_type'] + str(params['transaction_costs']) + str(params['normalization']) + salty
+        params = json.loads(run_json_string)
+        signal_name = mapping_df.iloc[0,mapping_df.columns.get_loc(col)]
+        human_readable_dictionary[signal_name] = readable_label
+        json_params_dictionary[signal_name] = params
+    return human_readable_dictionary, json_params_dictionary
+
 class ParallelRunResultAnalyzer():
 
     def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite'):
